# This file was auto-generated by Fern from our API Definition.

import enum
import typing

T_Result = typing.TypeVar("T_Result")


class AppointmentSortField(str, enum.Enum):
    START_TIMESTAMP = "startTimestamp"
    UPDATED_AT = "updatedAt"

    def visit(
        self, start_timestamp: typing.Callable[[], T_Result], updated_at: typing.Callable[[], T_Result]
    ) -> T_Result:
        if self is AppointmentSortField.START_TIMESTAMP:
            return start_timestamp()
        if self is AppointmentSortField.UPDATED_AT:
            return updated_at()
